# PoaData

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**operation** | **str** |  | [optional] 
**poa_id** | **str** |  | [optional] 
**state** | **str** |  | [optional] 
**sliver_id** | **str** |  | [optional] 
**slice_id** | **str** |  | [optional] 
**error** | **str** |  | [optional] 
**info** | **object** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

